==> mrpt_0.9.6.orig.tar.gz: mrpt-0.9.6/libs/base/src/utils/mrpt_font_6x13O.h <==
/* +---------------------------------------------------------------------------+
   |          The Mobile Robot Programming Toolkit (MRPT) C++ library          |
   |                                                                           |
   |                       http://www.mrpt.org/                                |
   |                                                                           |
   |   Copyright (C) 2005-2012  University of Malaga                           |
   |                                                                           |
   |    This software was written by the Machine Perception and Intelligent    |
   |      Robotics Lab, University of Malaga (Spain).                          |
   |    Contact: Jose-Luis Blanco  <jlblanco@ctima.uma.es>                     |
   |                                                                           |
   |  This file is part of the MRPT project.                                   |
   |                                                                           |
   |     MRPT is free software: you can redistribute it and/or modify          |
   |     it under the terms of the GNU General Public License as published by  |
   |     the Free Software Foundation, either version 3 of the License, or     |
   |     (at your option) any later version.                                   |
   |                                                                           |
   |   MRPT is distributed in the hope that it will be useful,                 |
   |     but WITHOUT ANY WARRANTY; without even the implied warranty of        |
   |     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         |
   |     GNU General Public License for more details.                          |
   |                                                                           |
   |     You should have received a copy of the GNU General Public License     |
   |     along with MRPT.  If not, see <http://www.gnu.org/licenses/>.         |
   |                                                                           |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_6x13O [] = {
31,139,8,0,0,0,0,0,4,3,237,154,217,110,36,69,
16,69,77,3,195,34,246,125,167,198,178,70,102,30,16,66,
8,205,131,53,255,255,87,16,167,187,143,185,142,201,170,78,
51,72,188,84,72,209,153,149,21,75,198,141,200,165,219,126,
114,117,117,245,97,49,244,215,169,57,126,62,63,247,175,91,
251,233,249,249,203,115,187,55,59,2,59,2,59,2,59,2,
59,2,255,55,2,239,214,4,146,223,170,103,153,185,209,239,
116,91,3,240,23,253,197,133,103,228,225,151,231,246,231,106,
223,63,115,53,175,16,243,186,43,86,230,135,234,223,20,99,
227,227,226,209,220,120,207,57,140,204,39,197,216,64,14,27,
156,191,239,21,143,8,57,231,247,65,245,145,255,165,248,219,
226,175,138,59,97,91,251,253,221,232,89,89,230,2,31,26,
59,206,60,36,198,120,134,245,103,235,184,182,212,177,229,61,
56,128,53,184,209,18,63,242,91,164,221,159,74,200,57,109,
201,175,189,3,195,181,185,165,14,126,94,135,240,241,81,113,
143,107,169,49,88,220,137,203,249,188,81,125,184,19,50,212,
0,247,55,153,187,27,76,61,116,31,53,116,204,141,245,34,
118,200,201,212,120,39,242,161,125,231,151,115,27,233,144,191,
165,88,121,108,248,204,252,192,160,147,181,242,77,189,176,182,
63,171,62,246,157,107,215,193,143,181,249,93,245,159,21,47,
197,216,90,243,99,60,234,49,23,113,91,211,201,120,140,73,
204,180,83,102,30,144,126,196,142,218,185,228,167,235,240,44,
46,107,115,211,41,24,33,79,43,49,199,81,189,249,126,164,
179,182,22,150,82,202,216,137,91,12,176,195,187,45,2,67,
105,84,51,190,211,174,54,151,122,129,109,230,197,187,209,90,
72,220,150,146,201,121,214,227,112,45,164,14,181,195,126,227,
158,139,15,242,213,137,57,245,53,71,44,153,215,174,131,157,
155,96,252,82,215,50,103,67,39,231,70,188,50,115,130,215,
234,160,251,193,167,62,104,71,126,200,137,246,105,177,161,31,
218,81,158,46,233,160,215,105,20,15,103,149,184,141,246,131,
235,122,159,140,95,229,109,71,126,200,81,178,53,74,59,242,
243,162,198,169,151,100,245,57,127,159,20,119,114,94,224,202,
94,139,204,219,197,200,175,205,13,124,59,95,194,90,63,127,
150,46,231,35,172,125,219,26,122,64,232,176,15,194,234,36,
214,232,117,50,63,250,163,213,62,237,8,55,106,37,229,123,
237,108,213,65,234,233,135,181,135,31,242,144,52,242,3,206,
91,88,27,207,161,228,96,246,14,243,187,22,15,245,101,222,
109,179,118,232,119,202,56,236,27,207,154,31,229,108,93,163,
212,17,60,227,199,189,202,22,189,78,218,247,44,37,38,112,
192,159,115,156,209,65,47,113,232,58,224,182,20,139,175,242,
135,26,163,6,250,30,66,110,210,30,114,114,174,135,119,106,
60,73,153,212,53,79,250,78,121,252,56,78,171,172,243,211,
78,247,195,123,247,248,180,247,186,253,196,1,31,204,233,117,
136,248,150,98,240,39,159,107,119,127,113,163,117,45,153,127,
218,209,185,80,195,247,228,90,50,55,232,140,246,131,165,198,
229,187,234,95,23,167,31,124,111,145,126,136,7,95,107,126,
184,31,222,20,155,63,236,210,207,56,235,113,149,244,227,252,
208,39,23,221,159,246,105,189,91,170,99,92,35,39,228,22,
98,173,209,135,181,53,194,173,94,223,215,2,177,89,179,234,
186,215,229,57,164,61,218,181,51,8,187,73,35,219,51,115,
211,6,223,43,61,79,220,119,192,97,139,30,131,155,118,122,
126,122,94,148,203,150,28,146,27,243,67,77,91,175,180,35,
178,70,159,214,75,124,88,7,226,62,210,49,158,67,189,188,
100,95,125,227,33,87,216,222,138,71,223,214,52,58,248,34,
199,212,211,22,101,252,248,88,219,15,210,134,58,180,214,17,
62,183,72,29,106,193,58,24,157,63,105,3,29,246,84,235,
13,121,230,184,69,250,201,88,88,27,172,135,92,11,105,227,
101,61,32,131,31,100,200,81,238,187,245,120,197,58,32,198,
228,55,207,207,135,106,229,142,183,185,201,54,109,116,220,240,
159,178,244,127,59,143,165,30,190,147,110,234,1,108,201,199,
78,59,2,59,2,59,2,59,2,59,2,59,2,167,243,20,
28,242,92,205,179,180,159,193,202,114,7,227,76,229,222,193,
239,52,220,91,184,139,143,228,107,248,120,71,224,28,214,182,
178,220,13,56,151,253,127,138,234,190,66,220,91,240,199,125,
7,127,232,174,221,117,144,133,253,142,206,253,5,159,220,89,
244,93,221,7,148,177,211,135,148,181,61,141,158,62,243,251,
146,253,155,122,229,247,129,209,221,242,182,222,195,143,37,239,
186,96,205,111,86,207,138,191,47,6,111,48,24,125,255,65,
103,41,38,118,100,184,251,66,253,222,118,26,125,248,201,28,
197,25,172,97,158,103,8,127,75,49,247,197,89,98,174,91,
100,252,191,150,16,241,195,95,23,131,193,90,252,245,234,24,
59,237,99,200,223,114,70,249,219,178,67,205,192,224,156,245,
34,238,169,139,28,120,210,34,59,202,95,13,63,32,230,5,
166,180,232,173,221,213,235,213,61,121,103,191,31,248,23,29,
106,26,102,61,129,137,191,233,251,61,173,134,142,116,87,159,
228,39,217,245,103,123,146,92,255,100,237,252,23,36,174,216,
162,15,102,230,100,6,107,244,172,57,226,206,26,155,89,63,
196,123,27,204,51,107,168,211,104,110,75,9,189,40,70,135,
57,244,117,52,210,65,6,127,230,27,189,164,81,237,44,37,
176,229,7,125,124,65,180,48,24,30,138,193,35,49,169,199,
35,241,62,117,136,1,252,96,112,83,175,186,247,228,156,25,
64,119,70,135,58,161,38,161,89,157,219,146,197,54,52,171,
131,252,99,117,180,77,107,255,18,6,204,233,143,98,247,90,
90,214,25,191,161,114,174,194,63,22,119,178,70,201,137,236,
186,52,63,230,12,221,204,15,251,180,58,236,81,234,245,250,
206,252,204,234,100,126,102,117,18,235,89,157,140,7,44,196,
156,150,119,112,95,239,25,207,172,78,198,51,171,147,241,204,
234,212,116,143,231,199,77,181,50,251,41,125,246,94,184,255,
174,124,91,99,214,168,117,198,253,128,250,113,189,209,38,129,
11,24,65,204,77,61,90,117,46,225,54,163,211,113,155,209,
201,120,102,231,214,177,158,241,67,236,73,232,96,135,189,146,
245,215,49,171,161,227,189,230,174,218,223,207,252,188,90,152,
123,24,247,17,24,220,88,75,82,98,61,154,23,126,182,176,
158,213,73,172,103,117,18,183,89,157,92,63,234,96,39,215,
28,49,119,58,212,0,251,140,58,214,178,251,78,98,166,46,
185,176,238,201,9,156,127,159,28,125,95,72,188,169,159,165,
152,253,4,156,215,126,187,205,152,102,117,18,239,89,157,94,
219,51,115,203,28,205,248,113,94,180,208,140,206,73,242,159,
79,116,152,43,249,242,123,29,216,111,17,58,228,150,60,147,
75,235,154,124,48,38,245,252,160,67,126,82,71,89,219,158,
159,25,29,113,192,134,115,187,228,167,99,61,227,39,227,161,
94,89,7,185,22,250,218,102,62,25,207,172,78,198,51,171,
147,241,204,232,16,11,126,144,101,142,226,6,14,228,211,156,
86,247,1,101,93,251,183,156,212,65,175,83,226,54,235,39,
113,155,213,73,220,102,117,50,158,89,157,196,122,86,7,76,
172,23,250,212,39,4,54,240,22,45,245,18,63,156,69,158,
65,159,87,191,159,63,53,116,180,133,31,136,188,200,228,101,
102,79,84,222,156,174,233,36,214,179,58,137,219,172,78,214,
129,58,25,11,239,71,127,207,58,212,56,220,107,20,220,56,
75,216,131,96,105,52,183,75,126,254,6,124,43,163,116,24,
52,0,0,};

==> mrpt_1.0.0.orig.tar.gz: mrpt-1.0.0/libs/base/src/utils/mrpt_font_6x13O.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_6x13O [] = {
31,139,8,0,0,0,0,0,4,3,237,154,217,110,36,69,
16,69,77,3,195,34,246,125,167,198,178,70,102,30,16,66,
8,205,131,53,255,255,87,16,167,187,143,185,142,201,170,78,
51,72,188,84,72,209,153,149,21,75,198,141,200,165,219,126,
114,117,117,245,97,49,244,215,169,57,126,62,63,247,175,91,
251,233,249,249,203,115,187,55,59,2,59,2,59,2,59,2,
59,2,255,55,2,239,214,4,146,223,170,103,153,185,209,239,
116,91,3,240,23,253,197,133,103,228,225,151,231,246,231,106,
223,63,115,53,175,16,243,186,43,86,230,135,234,223,20,99,
227,227,226,209,220,120,207,57,140,204,39,197,216,64,14,27,
156,191,239,21,143,8,57,231,247,65,245,145,255,165,248,219,
226,175,138,59,97,91,251,253,221,232,89,89,230,2,31,26,
59,206,60,36,198,120,134,245,103,235,184,182,212,177,229,61,
56,128,53,184,209,18,63,242,91,164,221,159,74,200,57,109,
201,175,189,3,195,181,185,165,14,126,94,135,240,241,81,113,
143,107,169,49,88,220,137,203,249,188,81,125,184,19,50,212,
0,247,55,153,187,27,76,61,116,31,53,116,204,141,245,34,
118,200,201,212,120,39,242,161,125,231,151,115,27,233,144,191,
165,88,121,108,248,204,252,192,160,147,181,242,77,189,176,182,
63,171,62,246,157,107,215,193,143,181,249,93,245,159,21,47,
197,216,90,243,99,60,234,49,23,113,91,211,201,120,140,73,
204,180,83,102,30,144,126,196,142,218,185,228,167,235,240,44,
46,107,115,211,41,24,33,79,43,49,199,81,189,249,126,164,
179,182,22,150,82,202,216,137,91,12,176,195,187,45,2,67,
105,84,51,190,211,174,54,151,122,129,109,230,197,187,209,90,
72,220,150,146,201,121,214,227,112,45,164,14,181,195,126,227,
158,139,15,242,213,137,57,245,53,71,44,153,215,174,131,157,
155,96,252,82,215,50,103,67,39,231,70,188,50,115,130,215,
234,160,251,193,167,62,104,71,126,200,137,246,105,177,161,31,
218,81,158,46,233,160,215,105,20,15,103,149,184,141,246,131,
235,122,159,140,95,229,109,71,126,200,81,178,53,74,59,242,
243,162,198,169,151,100,245,57,127,159,20,119,114,94,224,202,
94,139,204,219,197,200,175,205,13,124,59,95,194,90,63,127,
150,46,231,35,172,125,219,26,122,64,232,176,15,194,234,36,
214,232,117,50,63,250,163,213,62,237,8,55,106,37,229,123,
237,108,213,65,234,233,135,181,135,31,242,144,52,242,3,206,
91,88,27,207,161,228,96,246,14,243,187,22,15,245,101,222,
109,179,118,232,119,202,56,236,27,207,154,31,229,108,93,163,
212,17,60,227,199,189,202,22,189,78,218,247,44,37,38,112,
192,159,115,156,209,65,47,113,232,58,224,182,20,139,175,242,
135,26,163,6,250,30,66,110,210,30,114,114,174,135,119,106,
60,73,153,212,53,79,250,78,121,252,56,78,171,172,243,211,
78,247,195,123,247,248,180,247,186,253,196,1,31,204,233,117,
136,248,150,98,240,39,159,107,119,127,113,163,117,45,153,127,
218,209,185,80,195,247,228,90,50,55,232,140,246,131,165,198,
229,187,234,95,23,167,31,124,111,145,126,136,7,95,107,126,
184,31,222,20,155,63,236,210,207,56,235,113,149,244,227,252,
208,39,23,221,159,246,105,189,91,170,99,92,35,39,228,22,
98,173,209,135,181,53,194,173,94,223,215,2,177,89,179,234,
186,215,229,57,164,61,218,181,51,8,187,73,35,219,51,115,
211,6,223,43,61,79,220,119,192,97,139,30,131,155,118,122,
126,122,94,148,203,150,28,146,27,243,67,77,91,175,180,35,
178,70,159,214,75,124,88,7,226,62,210,49,158,67,189,188,
100,95,125,227,33,87,216,222,138,71,223,214,52,58,248,34,
199,212,211,22,101,252,248,88,219,15,210,134,58,180,214,17,
62,183,72,29,106,193,58,24,157,63,105,3,29,246,84,235,
13,121,230,184,69,250,201,88,88,27,172,135,92,11,105,227,
101,61,32,131,31,100,200,81,238,187,245,120,197,58,32,198,
228,55,207,207,135,106,229,142,183,185,201,54,109,116,220,240,
159,178,244,127,59,143,165,30,190,147,110,234,1,108,201,199,
78,59,2,59,2,59,2,59,2,59,2,59,2,167,243,20,
28,242,92,205,179,180,159,193,202,114,7,227,76,229,222,193,
239,52,220,91,184,139,143,228,107,248,120,71,224,28,214,182,
178,220,13,56,151,253,127,138,234,190,66,220,91,240,199,125,
7,127,232,174,221,117,144,133,253,142,206,253,5,159,220,89,
244,93,221,7,148,177,211,135,148,181,61,141,158,62,243,251,
146,253,155,122,229,247,129,209,221,242,182,222,195,143,37,239,
186,96,205,111,86,207,138,191,47,6,111,48,24,125,255,65,
103,41,38,118,100,184,251,66,253,222,118,26,125,248,201,28,
197,25,172,97,158,103,8,127,75,49,247,197,89,98,174,91,
100,252,191,150,16,241,195,95,23,131,193,90,252,245,234,24,
59,237,99,200,223,114,70,249,219,178,67,205,192,224,156,245,
34,238,169,139,28,120,210,34,59,202,95,13,63,32,230,5,
166,180,232,173,221,213,235,213,61,121,103,191,31,248,23,29,
106,26,102,61,129,137,191,233,251,61,173,134,142,116,87,159,
228,39,217,245,103,123,146,92,255,100,237,252,23,36,174,216,
162,15,102,230,100,6,107,244,172,57,226,206,26,155,89,63,
196,123,27,204,51,107,168,211,104,110,75,9,189,40,70,135,
57,244,117,52,210,65,6,127,230,27,189,164,81,237,44,37,
176,229,7,125,124,65,180,48,24,30,138,193,35,49,169,199,
35,241,62,117,136,1,252,96,112,83,175,186,247,228,156,25,
64,119,70,135,58,161,38,161,89,157,219,146,197,54,52,171,
131,252,99,117,180,77,107,255,18,6,204,233,143,98,247,90,
90,214,25,191,161,114,174,194,63,22,119,178,70,201,137,236,
186,52,63,230,12,221,204,15,251,180,58,236,81,234,245,250,
206,252,204,234,100,126,102,117,18,235,89,157,140,7,44,196,
156,150,119,112,95,239,25,207,172,78,198,51,171,147,241,204,
234,212,116,143,231,199,77,181,50,251,41,125,246,94,184,255,
174,124,91,99,214,168,117,198,253,128,250,113,189,209,38,129,
11,24,65,204,77,61,90,117,46,225,54,163,211,113,155,209,
201,120,102,231,214,177,158,241,67,236,73,232,96,135,189,146,
245,215,49,171,161,227,189,230,174,218,223,207,252,188,90,152,
123,24,247,17,24,220,88,75,82,98,61,154,23,126,182,176,
158,213,73,172,103,117,18,183,89,157,92,63,234,96,39,215,
28,49,119,58,212,0,251,140,58,214,178,251,78,98,166,46,
185,176,238,201,9,156,127,159,28,125,95,72,188,169,159,165,
152,253,4,156,215,126,187,205,152,102,117,18,239,89,157,94,
219,51,115,203,28,205,248,113,94,180,208,140,206,73,242,159,
79,116,152,43,249,242,123,29,216,111,17,58,228,150,60,147,
75,235,154,124,48,38,245,252,160,67,126,82,71,89,219,158,
159,25,29,113,192,134,115,187,228,167,99,61,227,39,227,161,
94,89,7,185,22,250,218,102,62,25,207,172,78,198,51,171,
147,241,204,232,16,11,126,144,101,142,226,6,14,228,211,156,
86,247,1,101,93,251,183,156,212,65,175,83,226,54,235,39,
113,155,213,73,220,102,117,50,158,89,157,196,122,86,7,76,
172,23,250,212,39,4,54,240,22,45,245,18,63,156,69,158,
65,159,87,191,159,63,53,116,180,133,31,136,188,200,228,101,
102,79,84,222,156,174,233,36,214,179,58,137,219,172,78,214,
129,58,25,11,239,71,127,207,58,212,56,220,107,20,220,56,
75,216,131,96,105,52,183,75,126,254,6,124,43,163,116,24,
52,0,0,};
